Returns county polygons from: Siczewicz, Peter. U.S. Historical Counties (Generalized .001 deg) on the basis of year of interest Dataset is subset on basis of area of interest
subset_county_polygons(year, area_column, areas)
| year | int, the year of interest to be mapped (defines historical basis for counties) |
|---|---|
| area_column | chr, defines which column to use to specify area |
| areas | chr, vector of codes indicating HUCs, counties, states, regions, aquifers, etc. |
hc_sub dataframe, a subset of county polygon data
areas <- "Delaware" # 3 counties present day area_column <- "STATE_TERR" year <- 2010 hc_sub <- subset_county_polygons(year, area_column, areas) hc_sub$NAME#> [1] "KENT" "NEW CASTLE" "SUSSEX"areas <- "Maine" # 16 counties present day area_column <- "STATE_TERR" year <- 2010 hc_sub <- subset_county_polygons(year, area_column, areas) hc_sub$NAME#> [1] "ANDROSCOGGIN" "AROOSTOOK" "CUMBERLAND" "FRANKLIN" "HANCOCK" #> [6] "KENNEBEC" "KNOX" "LINCOLN" "OXFORD" "PENOBSCOT" #> [11] "PISCATAQUIS" "SAGADAHOC" "SOMERSET" "WALDO" "WASHINGTON" #> [16] "YORK"year <- 1850 # Maine had 13 counties in 1850; Delaware 3 hc_sub <- subset_county_polygons(year, area_column, areas) hc_sub$NAME#> [1] "AROOSTOOK" "CUMBERLAND" "FRANKLIN" "HANCOCK" "KENNEBEC" #> [6] "LINCOLN" "OXFORD" "PENOBSCOT" "PISCATAQUIS" "SOMERSET" #> [11] "WALDO" "WASHINGTON" "YORK"